#include <xc.h>

// CONFIG1
#pragma config FOSC = INTOSC    // Oscillator Selection (INTOSC oscillator: I/O function on CLKIN pin)
#pragma config WDTE = OFF       // Watchdog Timer Enable (WDT disabled)
#pragma config PWRTE = ON       // Power-up Timer Enable (PWRT enabled)
#pragma config MCLRE = OFF      // MCLR Pin Function Select (MCLR/VPP pin function is digital input)
#pragma config CP = OFF         // Flash Program Memory Code Protection (Program memory code protection is disabled)
#pragma config CPD = OFF        // Data Memory Code Protection (Data memory code protection is disabled)
#pragma config BOREN = ON       // Brown-out Reset Enable (Brown-out Reset enabled)
#pragma config CLKOUTEN = OFF   // Clock Out Enable (CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin)
#pragma config IESO = OFF       // Internal/External Switchover (Internal/External Switchover mode is disabled)
#pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enable (Fail-Safe Clock Monitor is disabled)

// CONFIG2
#pragma config WRT = OFF        // Flash Memory Self-Write Protection (Write protection off)
#pragma config PLLEN = OFF      // PLL Enable (4x PLL disabled)
#pragma config STVREN = ON      // Stack Overflow/Underflow Reset Enable (Stack Overflow or Underflow will cause a Reset)
#pragma config BORV = LO        // Brown-out Reset Voltage Selection (Brown-out Reset Voltage (Vbor), low trip point selected.)
#pragma config LVP = OFF        // Low-Voltage Programming Enable (High-voltage on MCLR/VPP must be used for programming)

#define _XTAL_FREQ 8000000

void DispNum(unsigned char dig, unsigned char num);

unsigned char num[] = {//Data of Digits 0-9 and .
        0b11000000,
        0b11111001,
        0b10100100,
        0b10110000,
        0b10011001,
        0b10010010,
        0b10000011,
        0b11111000,
        0b10000000,
        0b10011000,
        0b01111111
};

unsigned char dig[] = {
        0b00000001,
        0b00000010,
        0b00000100
};

void main(){
    OSCCON = 0b01110010;//8MHz
    ANSELA = 0b00001000;//RA3 as AN3
    ANSELB = 0b00000000;//All Digital I/O
    TRISA  = 0b00001000;//All Output (AN3 and RA5 is Input)
    TRISB  = 0b00000000;//All Output

    ADCON0bits.ADON = 1;// A/D converter module is operating
    ADCON1bits.ADFM = 1;//Right justified
    ADCON1bits.ADCS = 0b001;//Fosc/8
    ADCON1bits.ADNREF = 0;//VREF- is connected to VSS
    ADCON1bits.ADPREF = 0b11;//VREF+ is connected to internal Fixed Voltage Reference (FVR) module
    //ADCON1bits.ADPREF = 0b00;//VREF+ is connected to VDD
    FVRCONbits.FVREN = 1;//Fixed Voltage Reference is enabled
    //FVRCONbits.FVREN = 0;//Fixed Voltage Reference is disabled
    FVRCONbits.ADFVR = 0b11;//ADC Fixed Voltage Reference Peripheral output is 4x (4.096V)

    CM1CON0bits.C1ON = 0;//Comparator 1 is disabled
    CM2CON0bits.C2ON = 0;//Comparator 2 is disabled

    unsigned int i;
    unsigned int j;
    while(1){
        __delay_us(50);
        ADCON0bits.CHS = 0b00011;//AN3 is Analog input
        __delay_us(50);
        ADCON0bits.GO_nDONE = 1;// ADC start
        while(ADCON0bits.GO_nDONE){}// ADC waiting
        i = ADRESH*256+ADRESL;

        for(j=0; j<200; j++){//Interval
            DispNum(0, i%10);//1
            DispNum(1, (i/10)%10);//10
            DispNum(2, (i/100)%10);//100
        }
    }
}

void DispNum(unsigned char d, unsigned char n){
    LATA = dig[d];//DIG1-3
    LATB = num[n];//Digit
}